stacked_firebase_auth library
Classes
- Firebase
- The entry point for accessing Firebase.
- FirebaseApp
- Represents a single Firebase app instance.
- FirebaseAuthenticationResult
- FirebaseAuthenticationService
- Wraps the firebase auth functionality into a service
- FirebaseOptions
- The options used to configure a Firebase app.
- User
- A user account.
Constants
- defaultFirebaseAppName → const String
- The default Firebase application name.
Functions
-
getErrorMessageFromFirebaseException(
FirebaseAuthException exception) → String -
getMappedHost(
String originalHost) → String
Exceptions / Errors
- FirebaseAuthException
- Generic exception related to Firebase Authentication. Check the error code and message for more details.
- FirebaseException
- A generic class which provides exceptions in a Firebase-friendly format to users.